@@ -102,6 +102,8 @@ sub traduction {                # translation
                 "en", "Grille 9x9 normale", "Normal Grid 9x9",
                 "en", "Grille 6x6 facile", "Grid 6x6 easy",
                 "en", "Grille 8x8 pas facile", "Grid 8x8 not easy",
+                "en", "Grille 10x10 Difficile", "Grid 10x10 Difficult",
+                "en", "Grille 12x12 Trs difficile", "Grid 12x12 very difficult",
                 "en", "Grille 16x16 trs difficile", "Grid 16x16 very difficult",
                 "en", "Grille 4x4 trs facile\navec dessins d'animaux\npar dfaut", "very easy grid 4x4\nwith animals\nby defect",
                 "en", "Saisir une grille\npour la rsoudre", "To seize a grid\nto solve it",
@@ -152,6 +154,8 @@ sub traduction {                # translation
                 "ge", "Grille 9x9 normale", "Normal Gitter 9x9",
                 "ge", "Grille 6x6 facile", "Gitter 6x6 einfaches",
                 "ge", "Grille 8x8 pas facile", "Gitter 8x8 nicht einfaches",
+                "ge", "Grille 10x10 Difficile", "Gitter 10x10 Schwieriges",
+                "ge", "Grille 12x12 Trs difficile", "Gitter 12x12 sehr Schwieriges",
                 "ge", "Grille 16x16 trs difficile", "Gitter 16x16 sehr schwieriges",
                 "ge", "Grille 4x4 trs facile\navec dessins d'animaux\npar dfaut", "sehr einfaches\nGitter 4x4 mit Tieren\nmangels", 
                 "ge", "Saisir une grille\npour la rsoudre", "Ein Gitter erfassen,\num es zu lsen",
@@ -202,6 +206,8 @@ sub traduction {                # translation
                 "sp", "Grille 9x9 normale", "Normal rejilla 9x9",
                 "sp", "Grille 6x6 facile", "rejilla 6x6 fcil",
                 "sp", "Grille 8x8 pas facile", "rejilla 8x8 no fcil",
+                "sp", "Grille 10x10 Difficile", "rejilla 10x10 Dificil",
+                "sp", "Grille 12x12 Trs difficile", "rejilla 12x12 muy dificil",
                 "sp", "Grille 16x16 trs difficile", "rejilla 16x16 muy dificil",
                 "sp", "Grille 4x4 trs facile\navec dessins d'animaux\npar dfaut", "rejilla 4x4 muy fcil\ncon animales\npor defecto",
                 "sp", "Saisir une grille\npour la rsoudre", "Coger una rejilla\npara solucionarlo",
@@ -252,6 +258,8 @@ sub traduction {                # translation
                 "it", "Grille 9x9 normale", "Normale griglia 9x9",
                 "it", "Grille 6x6 facile", "Griglia 6x6 facile",
                 "it", "Grille 8x8 pas facile", "Griglia 8x8 non facile",
+                "it", "Grille 10x10 Difficile", "Griglia 10x10 Difficile",
+                "it", "Grille 12x12 Trs difficile", "Griglia 12x12 molto difficile",
                 "it", "Grille 16x16 trs difficile", "Griglia 16x16 molto difficile",
                 "it", "Grille 4x4 trs facile\navec dessins d'animaux\npar dfaut", "griglia 4x4\nmolto facile \ncon animali per difetto",
                 "it", "Saisir une grille\npour la rsoudre", "Afferrare una griglia\nper risolverla",
@@ -301,6 +309,8 @@ sub traduction {                # translation
                 "pt", "Grille 9x9 normale", "Normal grelha 9x9",
                 "pt", "Grille 6x6 facile", "grelha 6x6 fcil",
                 "pt", "Grille 8x8 pas facile", "grelha 8x8 no fcil",
+                "pt", "Grille 10x10 Difficile", "grelha 10x10 dificil",
+                "pt", "Grille 12x12 Trs difficile", "grelha 12x12 muito dificil",
                 "pt", "Grille 16x16 trs difficile", "grelha 16x16 muito dificil", 
                 "pt", "Grille 4x4 trs facile\navec dessins d'animaux\npar dfaut","grelha 4x4 muito fcil\ncom animais\npor defeito",
                 "pt", "Saisir une grille\npour la rsoudre", "Apreender uma grelha\npara resolver-o",
